#!/bin/bash

if [ $# != 2 ]; then
  echo "
  Compute the area of the simulation box ("Box-X" times "Box-Y" extracted
  from an energy file given in argument), and the projected area per lipid
  by dividing this area per the number of lipids in a __monolayer__ (half
  of the lipids in the box in first approximation).
  Usage: ./$0 <.edr file> <#lipids>
 
    > ./area.sh ener_dspc.edr 64
  "
else
  g_energy -f $1 -b 3000
  grep "#" energy.xvg > area.xvg
  grep "@" energy.xvg | sed 's/E\ (kJ\ mol\\S\-1\\N)/Box\ dimension\ (nm)/g' >> area.xvg
  echo "@ s2 legend \"Total area (nm\\S2\\N)\"" >> area.xvg
  echo "@ s3 legend \"Projected area per lipid (nm\\S2\\N)\"" >> area.xvg
  grep -v "#" energy.xvg | grep -v "@" | awk -v lipids=$2 '{printf "%14.6f%12.6f%12.6f%12.6f%12.6f\n",$1,$2,$3,$2*$3,$2*$3/lipids}' >> area.xvg
  rm energy.xvg
  value=0.000000
  sum=$(grep -v "#" area.xvg | grep -v "@" | awk '{print $5}' | while read area; do
    value=`echo "scale=6;$value+$area" | bc`
    echo $value
  done | tail -1)
  printf "Averaged projected area per lipid: %8.6f (nm²)\n\n" $(echo "scale=6;$sum/`grep -v "#" area.xvg | grep -v "@" | wc | awk '{print $1}'`" | bc)
fi
